Index: main/waeup.sirp/trunk/src/waeup/sirp/browser/pages.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/browser/pages.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/browser/pages.py	(revision 7186)
@@ -37,5 +37,5 @@
     ISessionConfiguration, ISessionConfigurationAdd, academic_sessions_vocab,
     IPasswordValidator)
-from waeup.sirp.permissions import get_users_with_local_roles, getAllRoles
+from waeup.sirp.permissions import get_users_with_local_roles, get_all_roles
 from waeup.sirp.university.catalog import search
 from waeup.sirp.university.vocabularies import course_levels
@@ -266,5 +266,5 @@
         site_url = self.url(grok.getSite())
         for local_role in local_roles.keys():
-            role_title = dict(getAllRoles())[local_role].title
+            role_title = dict(get_all_roles())[local_role].title
             objects_string = ''
             for object in local_roles[local_role]:
@@ -279,5 +279,5 @@
         site_roles_string = ''
         for site_role in site_roles:
-            role_title = dict(getAllRoles())[site_role].title
+            role_title = dict(get_all_roles())[site_role].title
             site_roles_string += '%s <br />' % role_title
         return site_roles_string
@@ -385,5 +385,5 @@
         local_roles_userfriendly = {}
         for local_role in local_roles:
-            role_title = dict(getAllRoles())[local_role].title
+            role_title = dict(get_all_roles())[local_role].title
             local_roles_userfriendly[role_title] = local_roles[local_role]
         return local_roles_userfriendly
@@ -394,5 +394,5 @@
         site_roles_userfriendly = []
         for site_role in site_roles:
-            role_title = dict(getAllRoles())[site_role].title
+            role_title = dict(get_all_roles())[site_role].title
             site_roles_userfriendly.append(role_title)
         return site_roles_userfriendly
Index: main/waeup.sirp/trunk/src/waeup/sirp/datacenter.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/datacenter.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/datacenter.py	(revision 7186)
@@ -12,5 +12,5 @@
 from waeup.sirp.interfaces import (IDataCenter, IDataCenterFile,
                                    IDataCenterStorageMovedEvent)
-from waeup.sirp.utils.helpers import copyFileSystemTree
+from waeup.sirp.utils.helpers import copy_filesystem_tree
 from waeup.sirp.utils.logger import Logger
 
@@ -80,5 +80,5 @@
         if move is True:
 
-            not_copied = copyFileSystemTree(self.storage, path,
+            not_copied = copy_filesystem_tree(self.storage, path,
                                             overwrite=overwrite)
         self.storage = path
Index: main/waeup.sirp/trunk/src/waeup/sirp/interfaces.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/interfaces.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/interfaces.py	(revision 7186)
@@ -81,11 +81,11 @@
     def getValues(self):
         # late import: in interfaces we should not import local modules
-        from waeup.sirp.permissions import getWAeUPRoleNames
-        return getWAeUPRoleNames()
+        from waeup.sirp.permissions import get_waeup_role_names
+        return get_waeup_role_names()
 
     def getTitle(self, value):
         # late import: in interfaces we should not import local modules
-        from waeup.sirp.permissions import getAllRoles
-        roles = dict(getAllRoles())
+        from waeup.sirp.permissions import get_all_roles
+        roles = dict(get_all_roles())
         if value in roles.keys():
             title = roles[value].title
Index: main/waeup.sirp/trunk/src/waeup/sirp/permissions.txt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/permissions.txt	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/permissions.txt	(revision 7186)
@@ -13,6 +13,6 @@
 roles.
 
-:func:`getAllRoles`
--------------------
+:func:`get_all_roles`
+---------------------
 
 Gives us all roles defined in a WAeUP SIRP portal. We get tuples of
@@ -24,33 +24,33 @@
 with the ZCA (a string) and ``<ROLE>`` is the real role object.
 
-    >>> from waeup.sirp.permissions import getAllRoles
-    >>> getAllRoles()
+    >>> from waeup.sirp.permissions import get_all_roles
+    >>> get_all_roles()
     <generator object...at 0x...>
 
-    >>> sorted(list(getAllRoles()))
+    >>> sorted(list(get_all_roles()))
     [(u'waeup.ACManager', <waeup.sirp.permissions.ACManager object at 0x...]
 
-:func:`getWAeUPRoles`
----------------------
+:func:`get_waeup_roles`
+-----------------------
 
 Gives us all roles, except the WAeUP specific roles. We can get a list
 with or without local roles:
 
-    >>> from waeup.sirp.permissions import getWAeUPRoles
-    >>> len(list(getWAeUPRoles()))
+    >>> from waeup.sirp.permissions import get_waeup_roles
+    >>> len(list(get_waeup_roles()))
     10
 
-    >>> len(list(getWAeUPRoles(also_local=True)))
+    >>> len(list(get_waeup_roles(also_local=True)))
     16
 
 
-:func:`getRoleNames`
---------------------
+:func:`get_waeup_role_names`
+----------------------------
 
 We can get all role names defined in a WAeUP portal (except 'local'
 roles that are meant not to be assigned globally):
 
-    >>> from waeup.sirp.permissions import getWAeUPRoleNames
-    >>> list(getWAeUPRoleNames())
+    >>> from waeup.sirp.permissions import get_waeup_role_names
+    >>> list(get_waeup_role_names())
     [u'waeup.ACManager', u'waeup.AcademicsOfficer',
      u'waeup.AccommodationOfficer', u'waeup.Applicant',
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py	(revision 7186)
@@ -737,5 +737,5 @@
             self.request)
         students_utils = getUtility(IStudentsUtils)
-        return students_utils.render_pdf(
+        return students_utils.renderPDF(
             self,'Course Registration', 'course_registration.pdf',
             self.context.getStudent, studentview)
@@ -1022,5 +1022,5 @@
                 return
         students_utils = getUtility(IStudentsUtils)
-        pay_details  = students_utils.get_payment_details(
+        pay_details  = students_utils.getPaymentDetails(
             p_category,student)
         if pay_details['error']:
@@ -1177,5 +1177,5 @@
             self.request)
         students_utils = getUtility(IStudentsUtils)
-        return students_utils.render_pdf(self,'Payment', 'payment_receipt.pdf',
+        return students_utils.renderPDF(self,'Payment', 'payment_receipt.pdf',
             self.context.getStudent, studentview)
 
@@ -1289,5 +1289,5 @@
         student = self.context.getStudent()
         students_utils = getUtility(IStudentsUtils)
-        acc_details  = students_utils.get_accommodation_details(student)
+        acc_details  = students_utils.getAccommodationDetails(student)
         if not student.state in acc_details['allowed_states']:
             self.flash("You are in the wrong registration state.")
@@ -1327,5 +1327,5 @@
             if available_beds:
                 students_utils = getUtility(IStudentsUtils)
-                bed = students_utils.select_bed(available_beds)
+                bed = students_utils.selectBed(available_beds)
                 bed.bookBed(student.student_id)
             else:
@@ -1409,5 +1409,5 @@
             self.request)
         students_utils = getUtility(IStudentsUtils)
-        return students_utils.render_pdf(
+        return students_utils.renderPDF(
             self,'Bed Allocation', 'bed_allocation.pdf',
             self.context.getStudent, studentview)
@@ -1434,5 +1434,5 @@
         student = self.context.getStudent()
         students_utils = getUtility(IStudentsUtils)
-        acc_details  = students_utils.get_accommodation_details(student)
+        acc_details  = students_utils.getAccommodationDetails(student)
         if self.context.bed != None and \
               'reserved' in self.context.bed.bed_type:
@@ -1462,5 +1462,5 @@
             if available_beds:
                 students_utils = getUtility(IStudentsUtils)
-                new_bed = students_utils.select_bed(available_beds)
+                new_bed = students_utils.selectBed(available_beds)
                 new_bed.bookBed(student.student_id)
             else:
@@ -1719,5 +1719,5 @@
 
     @grok.action('Save and request clearance')
-    def requestclearance(self, **data):
+    def requestClearance(self, **data):
         self.applyData(self.context, **data)
         self.context._p_changed = True
@@ -1964,5 +1964,5 @@
 
     @grok.action('Register course list')
-    def register_courses(self, **data):
+    def RegisterCourses(self, **data):
         state = IWorkflowState(self.context.getStudent()).getState()
         IWorkflowInfo(self.context.getStudent()).fireTransition('register_courses')
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/interfaces.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/interfaces.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/interfaces.py	(revision 7186)
@@ -30,5 +30,5 @@
 
     """
-    def get_payment_details(category, student):
+    def getPaymentDetails(category, student):
         """Get the payment dates of a student for the payment category
         specified.
@@ -36,10 +36,10 @@
         """
 
-    def get_accommodation_details(student):
+    def getAccommodation_details(student):
         """Determine the accommodation dates of a student.
 
         """
 
-    def select_bed(available_beds):
+    def selectBed(available_beds):
         """Select a bed from a list of available beds.
 
@@ -48,5 +48,5 @@
         """
 
-    def render_pdf(view, subject='', filename='slip.pdf',):
+    def renderPDF(view, subject='', filename='slip.pdf',):
         """Render pdf slips for various pages.
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/utils.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/utils.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/utils.py	(revision 7186)
@@ -35,5 +35,5 @@
     return
 
-def setUpWidgets(view, ignore_request=False):
+def set_up_widgets(view, ignore_request=False):
     view.adapters = {}
     view.widgets = setUpEditWidgets(
@@ -44,5 +44,5 @@
 
 def render_student_data(student, studentview):
-    setUpWidgets(studentview, ignore_request=True)
+    set_up_widgets(studentview, ignore_request=True)
     data = []
     style = getSampleStyleSheet()
@@ -63,5 +63,5 @@
     grok.implements(IStudentsUtils)
 
-    def get_payment_details(self,category, student):
+    def getPaymentDetails(self,category, student):
         d = {}
         d['p_item'] = u''
@@ -85,9 +85,9 @@
             d['amount'] = academic_session.clearance_fee
         elif category == 'bed_allocation':
-            d['p_item'] = self.get_accommodation_details(student)['bt']
+            d['p_item'] = self.getAccommodationDetails(student)['bt']
             d['amount'] = academic_session.booking_fee
         return d
 
-    def get_accommodation_details(self, student):
+    def getAccommodationDetails(self, student):
         d = {}
         d['error'] = u''
@@ -117,8 +117,8 @@
     # In the standard configuration we select the first bed found,
     # but can also randomize the selection if we like.
-    def select_bed(self, available_beds):
+    def selectBed(self, available_beds):
         return available_beds[0]
 
-    def render_pdf(self, view, subject='', filename='slip.pdf',
+    def renderPDF(self, view, subject='', filename='slip.pdf',
         student=None, studentview=None):
         # (0,0),(-1,-1) = whole table
@@ -153,5 +153,5 @@
             story.append(studenttable)
         story.append(Spacer(1, 18))
-        setUpWidgets(view)
+        set_up_widgets(view)
         data = []
         for widget in view.widgets:
Index: main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.py	(revision 7186)
@@ -19,5 +19,5 @@
 BUFSIZE = 8 * 1024
 
-def removeFileOrDirectory(filepath):
+def remove_file_or_directory(filepath):
     """Remove a file or directory.
 
@@ -35,5 +35,5 @@
     return
 
-def copyFileSystemTree(src, dst, overwrite=False, del_old=False):
+def copy_filesystem_tree(src, dst, overwrite=False, del_old=False):
     """Copy contents of directory src to directory dst.
 
@@ -68,5 +68,5 @@
         if os.path.exists(itemdst):
             if overwrite is True:
-                removeFileOrDirectory(itemdst)
+                remove_file_or_directory(itemdst)
             else:
                 not_copied.append(item)
@@ -78,9 +78,9 @@
             shutil.copy2(itemsrc, itemdst)
         if del_old:
-            removeFileOrDirectory(itemsrc)
+            remove_file_or_directory(itemsrc)
     return not_copied
 
 
-def getInnerHTMLPart(html_code):
+def get_inner_HTML_part(html_code):
     """Return the 'inner' part of a complete HTML snippet.
 
@@ -95,5 +95,5 @@
 
        >>> doc = '<html><form>My Form</form>Outside the form</html>'
-       >>> getInnerHTMLPart(doc)
+       >>> get_inner_HTML_part(doc)
        '<form>My Form</form>'
 
@@ -101,5 +101,5 @@
 
        >>> doc = '<html><body>My Body</body>Trailing Trash</html>'
-       >>> getInnerHTMLPart(doc)
+       >>> get_inner_HTML_part(doc)
        'My Body'
 
@@ -107,5 +107,5 @@
 
        >>> doc = '<html>without body nor form</html>'
-       >>> getInnerHTMLPart(doc)
+       >>> get_inner_HTML_part(doc)
        '<html>without body nor form</html>'
 
@@ -309,5 +309,5 @@
     if warning_msgs == '':
         warning_msgs = None
-    result = getInnerHTMLPart(fulldoc).strip()
+    result = get_inner_HTML_part(fulldoc).strip()
     if not isinstance(result, unicode):
         result = result.decode('utf-8')
Index: main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.txt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.txt	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.txt	(revision 7186)
@@ -8,18 +8,18 @@
 .. :doctest:
 
-:func:`removeFileOrDirectory`
-=============================
-
-.. function:: removeFileOrDirectory(path)
+:func:`remove_file_or_directory`
+================================
+
+.. function:: remove_file_or_directory(path)
 
    Removes a file or directory given by a path. We can remove files:
 
      >>> import os
-     >>> from waeup.sirp.utils.helpers import removeFileOrDirectory
+     >>> from waeup.sirp.utils.helpers import remove_file_or_directory
      >>> open('blah', 'wb').write('nonsense')
      >>> 'blah' in os.listdir('.')
      True
 
-     >>> removeFileOrDirectory('blah')
+     >>> remove_file_or_directory('blah')
      >>> 'blah' in os.listdir('.')
      False
@@ -31,13 +31,13 @@
      True
 
-     >>> removeFileOrDirectory('blah')
+     >>> remove_file_or_directory('blah')
      >>> 'blah' in os.listdir('.')
      False
 
 
-:func:`copyFileSystemTree`
-==========================
-
-.. function:: copyFileSystemTree(src_path, dst_path[, overwrite=False[, del_old=False]])
+:func:`copy_filesystem_tree`
+============================
+
+.. function:: ccopy_filesystem_tree(src_path, dst_path[, overwrite=False[, del_old=False]])
 
    Copies the contents of an (existing) directory to another
@@ -67,6 +67,6 @@
      >>> open(os.path.join('src', 'blah'), 'wb').write('nonsense')
 
-     >>> from waeup.sirp.utils.helpers import copyFileSystemTree
-     >>> result = copyFileSystemTree('src', 'dst')
+     >>> from waeup.sirp.utils.helpers import copy_filesystem_tree
+     >>> result = copy_filesystem_tree('src', 'dst')
 
    As a result we get a list of non-copied files:
@@ -83,5 +83,5 @@
 
      >>> open(os.path.join('src', '.blah'), 'wb').write('nonsense')
-     >>> result = copyFileSystemTree('src', 'dst')
+     >>> result = copy_filesystem_tree('src', 'dst')
      >>> '.blah' in os.listdir('dst')
      False
@@ -100,5 +100,5 @@
 
     >>> open(os.path.join('src', 'blah'), 'wb').write('newnonsense')
-    >>> result = copyFileSystemTree('src', 'dst')
+    >>> result = copy_filesystem_tree('src', 'dst')
     >>> open(os.path.join('dst', 'blah'), 'rb').read()
     'nonsense'
@@ -113,5 +113,5 @@
 overwritten:
 
-    >>> result = copyFileSystemTree('src', 'dst', overwrite=True)
+    >>> result = copy_filesystem_tree('src', 'dst', overwrite=True)
     >>> open(os.path.join('dst', 'blah'), 'rb').read()
     'newnonsense'
@@ -129,5 +129,5 @@
     ...   'dst', 'mydir', 'blah'), 'wb').write('dstblah')
 
-    >>> result = copyFileSystemTree('src', 'dst', overwrite=True)
+    >>> result = copy_filesystem_tree('src', 'dst', overwrite=True)
     >>> open(os.path.join('dst', 'mydir', 'blah'), 'rb').read()
     'srcblah'
@@ -140,5 +140,5 @@
 removed from the src dir. Default is `False`.
 
-    >>> result = copyFileSystemTree('src', 'dst', overwrite=True, 
+    >>> result = copy_filesystem_tree('src', 'dst', overwrite=True,
     ...                                           del_old=True)
     >>> os.listdir('src')
@@ -151,12 +151,12 @@
 Clean up:
 
-    >>> removeFileOrDirectory('src')
-    >>> removeFileOrDirectory('dst')
-
-
-:func:`getInnerHTMLPart()`
-==========================
-
-.. function:: getInnerHTMLPart(html_code)
+    >>> remove_file_or_directory('src')
+    >>> remove_file_or_directory('dst')
+
+
+:func:`get_inner_HTML_part()`
+=============================
+
+.. function:: get_inner_HTML_part(html_code)
 
    Get the 'inner' part out of a piece of HTML code.
@@ -172,6 +172,6 @@
    returned with all preceeding/following stuff stripped:
 
-     >>> from waeup.sirp.utils.helpers import getInnerHTMLPart
-     >>> print getInnerHTMLPart("""<html>
+     >>> from waeup.sirp.utils.helpers import get_inner_HTML_part
+     >>> print get_inner_HTML_part("""<html>
      ... <head>
      ... </head>
@@ -198,5 +198,5 @@
    If there is no ``<form>`` part, try to find any ``<body>`` part:
 
-     >>> print getInnerHTMLPart("""<html>
+     >>> print get_inner_HTML_part("""<html>
      ... <head>
      ... </head>
@@ -213,5 +213,5 @@
    If there is also no ``<body>`` tag, we return the input as-is:
 
-     >>> print getInnerHTMLPart("""<div>
+     >>> print get_inner_HTML_part("""<div>
      ...  <div>Some content</div>
      ... </div>
Index: main/waeup.sirp/trunk/src/waeup/sirp/permissions.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/permissions.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/permissions.py	(revision 7186)
@@ -97,10 +97,10 @@
                      'waeup.viewHostels', 'waeup.manageHostels')
 
-def getAllRoles():
+def get_all_roles():
     """Return a list of tuples ``<ROLE-NAME>, <ROLE>``.
     """
     return getUtilitiesFor(IRole)
 
-def getWAeUPRoles(also_local=False):
+def get_waeup_roles(also_local=False):
     """Get all WAeUP roles.
 
@@ -114,5 +114,5 @@
     Returns a generator of the found roles.
     """
-    for name, item in getAllRoles():
+    for name, item in get_all_roles():
         if not name.startswith('waeup.'):
             # Ignore non-WAeUP roles...
@@ -123,12 +123,12 @@
         yield item
 
-def getWAeUPRoleNames():
+def get_waeup_role_names():
     """Get the ids of all WAeUP roles.
 
     See :func:`getWAeUPRoles` for what a 'WAeUPRole' is.
 
     This function returns a sorted list of WAeUP role names.
     """
-    return sorted([x.id for x in getWAeUPRoles()])
+    return sorted([x.id for x in get_waeup_roles()])
 
 class LocalRolesAssignable(grok.Adapter):
@@ -160,5 +160,5 @@
         self.context = context
         role_ids = getattr(context, 'local_roles', self._roles)
-        self._roles = [(name, role) for name, role in getAllRoles()
+        self._roles = [(name, role) for name, role in get_all_roles()
                        if name in role_ids]
         return
@@ -191,5 +191,5 @@
         user = grok.getSite()['users'].get(user_name,None)
         user_title = getattr(user, 'description', user_name)
-        local_role_title = dict(getAllRoles())[local_role].title
+        local_role_title = dict(get_all_roles())[local_role].title
         yield dict(user_name = user_name,
                    user_title = user_title,
@@ -123,12 +123,12 @@
     """Get the ids of all WAeUP roles.
 
-    See :func:`getWAeUPRoles` for what a 'WAeUPRole' is.
+    See :func:`get_waeup_roles` for what a 'WAeUPRole' is.
 
     This function returns a sorted list of WAeUP role names.
Index: main/waeup.sirp/trunk/src/waeup/sirp/utils/tests/test_helpers.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/utils/tests/test_helpers.py	(revision 7185)
+++ main/waeup.sirp/trunk/src/waeup/sirp/utils/tests/test_helpers.py	(revision 7186)
@@ -54,10 +54,10 @@
 
     def test_handle_not_existing_path(self):
-        result = helpers.removeFileOrDirectory(self.non_file)
+        result = helpers.remove_file_or_directory(self.non_file)
         self.assertTrue(result is None)
         return
 
     def test_handle_dir(self):
-        helpers.removeFileOrDirectory(self.dirpath)
+        helpers.remove_file_or_directory(self.dirpath)
         self.assertFalse(
             os.path.exists(self.dirpath)
@@ -66,5 +66,5 @@
 
     def test_handle_file(self):
-        helpers.removeFileOrDirectory(self.filepath)
+        helpers.remove_file_or_directory(self.filepath)
         self.assertFalse(
             os.path.exists(self.filepath)
@@ -73,5 +73,5 @@
 
 class CopyFileSystemTreeTestCase(unittest.TestCase):
     # Test edge cases of copyFileSystemTree().
     #
     # This is a typical case of tests not written as doctest as it is
@@ -94,5 +94,5 @@
 
     def test_source_and_dst_existing(self):
-        helpers.copyFileSystemTree(self.existing_src, self.existing_dst)
+        helpers.copy_filesystem_tree(self.existing_src, self.existing_dst)
         self.assertTrue(
             os.path.exists(
@@ -105,5 +105,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.not_existing_dir,
             self.existing_dst
@@ -114,5 +114,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.existing_src,
             self.not_existing_dir
@@ -123,5 +123,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.filepath,
             self.existing_dst
@@ -132,5 +132,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.existing_src,
             self.filepath
@@ -73,5 +73,5 @@
 
 class CopyFileSystemTreeTestCase(unittest.TestCase):
-    # Test edge cases of copyFileSystemTree().
+    # Test edge cases of copy_filesystem_tree().
     #
     # This is a typical case of tests not written as doctest as it is
